@@ -12,9 +12,9 @@ import (
 	"k8s.io/klog"
 	"sigs.k8s.io/controller-runtime/pkg/client/config"
 
-	clusterclientset "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
-	"github.com/open-cluster-management/rbac-query-proxy/pkg/proxy"
-	"github.com/open-cluster-management/rbac-query-proxy/pkg/util"
+	"github.com/stolostron/rbac-query-proxy/pkg/proxy"
+	"github.com/stolostron/rbac-query-proxy/pkg/util"
+	clusterclientset "open-cluster-management.io/api/client/cluster/clientset/versioned"
 )
 
 const (
